@@ -40,9 +40,10 @@
 #include "sumpt.h"
 #include "utils.h"
 
-       const char* const svnRevisionBayesC = "$Rev: 914 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
+       const char* const svnRevisionBayesC = "$Rev: 1008 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
 extern const char* const svnRevisionBestC;
 extern const char* const svnRevisionCommandC;
+extern const char* const svnRevisionLikeliC;
 extern const char* const svnRevisionMbbeagleC;
 extern const char* const svnRevisionMcmcC;
 extern const char* const svnRevisionModelC;
@@ -139,7 +140,7 @@ int main (int argc, char *argv[])
         lastError = GetLastError();
         GetConsoleScreenBufferInfo(scbh, &csbi);
         sprintf(poltmp, "\nlastError = %d", lastError);
-        printf (poltmp);
+        // printf (poltmp);
         }
 #   endif
 
@@ -478,9 +479,9 @@ int InitializeMrBayes (void)
     echoMB               = YES;                      /* flag used by Manual to control printing       */
 
 #   if defined (MPI_ENABLED)
-    sprintf (manFileName, "commref_mb%sp.txt", VERSION_NUMBER);  /* name of command reference file     */
+    sprintf (manFileName, "commref_mb%sp.txt", VERSION_NUMBER);  /* name of command reference file    */
 #   else
-    sprintf (manFileName, "commref_mb%s.txt", VERSION_NUMBER);   /* name of command reference file     */
+    sprintf (manFileName, "commref_mb%s.txt", VERSION_NUMBER);   /* name of command reference file    */
 #   endif
 
     for (i=0; i<NUM_ALLOCS; i++)                     /* set allocated memory to NO                    */
@@ -509,9 +510,9 @@ int InitializeMrBayes (void)
 #       if defined (WIN_VERSION)
     tryToUseBEAGLE = NO;                             /* try to use the BEAGLE library (NO until SSE code works in Win) */
 #       else
-    tryToUseBEAGLE = NO;                             /* try to use the BEAGLE library if not Windows (NO untill SSE single prec. works)*/
+    tryToUseBEAGLE = NO;                             /* try to use the BEAGLE library if not Win (NO untill SSE single prec. works) */
 #       endif
-    beagleScalingScheme = MB_BEAGLE_SCALE_ALWAYS;    /* use BEAGLE dynamic scaling                    */
+    beagleScalingScheme = MB_BEAGLE_SCALE_ALWAYS;    /* use BEAGLE always scaling                     */
     beagleFlags = BEAGLE_FLAG_PROCESSOR_CPU;         /* default to generic CPU                        */
     beagleResourceNumber = 99;                       /* default to auto-resource selection            */
     // SSE instructions do not work in Windows environment
@@ -650,7 +651,7 @@ int InitializeMrBayes (void)
         defaultModel.stateFreqsDir[i] = 1.0;
         }    
     defaultModel.numDirParams = 0;
-    strcpy(defaultModel.shapePr, "Exponential");        /* prior for gamma shape parameter              */
+    strcpy(defaultModel.shapePr, "Exponential");        /* prior for gamma/lnorm shape parameter        */
     defaultModel.shapeFix = 0.5;
     defaultModel.shapeUni[0] = MIN_SHAPE_PARAM;
     defaultModel.shapeUni[1] = MAX_SHAPE_PARAM;
@@ -739,14 +740,14 @@ int InitializeMrBayes (void)
     defaultModel.sampleProb = 1.0;                      /* extant taxon sampling fraction               */
     defaultModel.sampleFSNum = 0;                       /* number of fossil slice sampling events       */
 
-    strcpy(defaultModel.popSizePr, "Lognormal");        /* prior on coalescence population size         */
+    strcpy(defaultModel.popSizePr, "Gamma");            /* prior on coalescence population size         */
     defaultModel.popSizeFix = 100.0;                    /* N_e = 100 */
     defaultModel.popSizeUni[0] = 0.0;
     defaultModel.popSizeUni[1] = 1000.0;
     defaultModel.popSizeNormal[0] = 100.0;
     defaultModel.popSizeNormal[1] = 30.0;
     defaultModel.popSizeLognormal[0] = 4.6;             /* mean on log scale corresponds to N_e = 100.0 */
-    defaultModel.popSizeLognormal[1] = 2.3;             /* factor 10 in one standard deviation          */
+    defaultModel.popSizeLognormal[1] = 0.4;             /* factor 10 in one standard deviation          */
     defaultModel.popSizeGamma[0] = 1.0;                 /* exponential with mean 1/10 = 0.1 */
     defaultModel.popSizeGamma[1] = 10.0;
     strcpy(defaultModel.popVarPr, "Equal");             /* prior on pop. size variation across tree     */
@@ -852,8 +853,8 @@ void PrintHeader (void)
 {
     char arch[4];
 #   ifndef RELEASE
-    unsigned rev = FindMaxRevision (9, svnRevisionBayesC,svnRevisionBestC,svnRevisionCommandC,svnRevisionMbbeagleC,
-                                       svnRevisionMcmcC,svnRevisionModelC,svnRevisionProposalC,svnRevisionSumptC,svnRevisionUtilsC);
+    unsigned rev = FindMaxRevision (10, svnRevisionBayesC,svnRevisionBestC,svnRevisionCommandC,svnRevisionLikeliC,svnRevisionMbbeagleC,
+                                        svnRevisionMcmcC,svnRevisionModelC,svnRevisionProposalC,svnRevisionSumptC,svnRevisionUtilsC);
 #   endif
 
     strcpy(arch,(sizeof(void*)==4)?"x86":"x64");
@@ -946,7 +947,7 @@ int ReinitializeMrBayes (void)
     chainParams.autotune = YES;                      /* autotune?                                     */
     chainParams.tuneFreq = 100;                      /* autotuning frequency                          */
     chainParams.checkPoint = YES;                    /* should we checkpoint the run?                 */
-    chainParams.checkFreq = 100000;                  /* check-pointing frequency                      */
+    chainParams.checkFreq = 2000;                    /* check-pointing frequency                      */
     chainParams.diagnStat = AVGSTDDEV;               /* mcmc diagnostic to use                        */
 
     /* sumt parameters */
