@@ -20,7 +20,7 @@
 #   define PACKAGE_VERSION "3.2"
 #   undef  HAVE_LIBREADLINE
 #   define UNIX_VERSION 1
-#   undef  SSE_ENABLED
+#   define SSE_ENABLED  1
 #   undef  MPI_ENABLED
 #   undef  BEAGLE_ENABLED
 #   undef  FAST_LOG
@@ -37,12 +37,12 @@
 /* uncomment the following line when releasing, also modify the VERSION_NUMBER below */
 #define RELEASE
 #ifdef RELEASE
-#define VERSION_NUMBER          "3.2.3"
+#define VERSION_NUMBER  "3.2.5"
 #else
-#define VERSION_NUMBER          "3.2.3-svn"
+#define VERSION_NUMBER  "3.2.6-svn"
 #endif
 
-#if !defined(UNIX_VERSION) && !defined(WIN_VERSION) && !defined(MAC_VERSION)
+#if !defined (UNIX_VERSION) && !defined (WIN_VERSION) && !defined (MAC_VERSION)
 #  ifdef __MWERKS__
 #    define MAC_VERSION
 #  elif defined __APPLE__
@@ -242,8 +242,8 @@ typedef float CLFlt;        /* single-precision float used for cond likes (CLFlt
 #define AMPERSAND               28
 
 #define MAX_Q_RATE              100.0f
-#define MIN_SHAPE_PARAM         0.0001f
-#define MAX_SHAPE_PARAM         200.0f
+#define MIN_SHAPE_PARAM         0.00001f
+#define MAX_SHAPE_PARAM         100.0f
 #define MAX_SITE_RATE           10.0f
 #define MAX_GAMMA_CATS          20
 #define MAX_GAMMA_CATS_SQUARED  400
@@ -255,7 +255,7 @@ typedef float CLFlt;        /* single-precision float used for cond likes (CLFlt
 #define RELBRLENS_MIN           0.00000001f  // 1E-8f
 #define RELBRLENS_MAX           100.0f
 #define KAPPA_MIN               0.001f
-#define KAPPA_MAX               10000.0f
+#define KAPPA_MAX               1000.0f
 #define GROWTH_MIN              0.000001f
 #define GROWTH_MAX              1000000.0f
 #define RATE_MIN                0.000001f
@@ -282,7 +282,8 @@ typedef float CLFlt;        /* single-precision float used for cond likes (CLFlt
 #define IGRVAR_MAX              10000.0f
 #define MIXEDVAR_MIN            0.000001f
 #define MIXEDVAR_MAX            10000.0f
-#define OMEGA_MAX               1000000.0f
+#define OMEGA_MIN               0.001f
+#define OMEGA_MAX               1000.0f
 
 #define POS_MIN                 1E-25f
 #define POS_MAX                 1E25f
@@ -489,16 +490,16 @@ typedef struct node
     int             index;                  /*!< index to node (0 to numLocalTaxa for tips) */
     int             upDateCl;               /*!< cond likes need update?                    */
     int             upDateTi;               /*!< transition probs need update?              */
-    int             marked, x, y;           /*!< scratch variables                          */
     int             scalerNode;             /*!< is node scaling cond likes?                */
     int             isLocked;               /*!< is node locked?                            */
     int             lockID;                 /*!< id of lock                                 */
     int             isDated;                /*!< is node dated (calibrated)?                */
+    int             marked, x, y;           /*!< scratch variables                          */
+    MrBFlt          d;                      /*!< scratch variable                           */
     BitsLong        *partition;             /*!< pointer to bitfield describing splits      */
     MrBFlt          length;                 /*!< length of pending branch                   */
     MrBFlt          nodeDepth;              /*!< node depth (height)                        */
     MrBFlt          age;                    /*!< age of node                                */
-    MrBFlt          d;                      /*!< scratch variable                           */
     Calibration     *calibration;           /*!< pointer to calibration data                */
     }
     TreeNode;
@@ -815,13 +816,13 @@ typedef struct
     char         *shortName;         /* abbreviated name of the move type            */
     char         *paramName;         /* name of subparameter if complex parameter    */
     int          subParams;          /* are we changing subparams (brlens of topol.) */
-    char         *tuningName[3];     /* name of tuning params                        */
-    char         *shortTuningName[3];/* short name of tuning params                  */
+    char         *tuningName[5];     /* name of tuning params                        */
+    char         *shortTuningName[5];/* short name of tuning params                  */
     MrBFlt       relProposalProb;    /* default relative proposal probability        */
     int          numTuningParams;    /* number of tuning parameters                  */
-    MrBFlt       tuningParam[3];     /* default tuning parameters for the proposal   */
-    MrBFlt       minimum[3];         /* minimum values for tuning params             */
-    MrBFlt       maximum[3];         /* maximum values for tuning params             */
+    MrBFlt       tuningParam[5];     /* default tuning parameters for the proposal   */
+    MrBFlt       minimum[5];         /* minimum values for tuning params             */
+    MrBFlt       maximum[5];         /* maximum values for tuning params             */
     int          parsimonyBased;     /* this move is based on parsimony (YES/NO)     */
     int          level;              /* user level of this move                      */
     AutotuneFxn  *Autotune;          /* pointer to the autotuning function           */
@@ -955,7 +956,7 @@ typedef struct model
     MrBFlt      stateFreqsDir[200];
     char        stateFreqsFixType[100];
     int         numDirParams;
-    char        shapePr[100];      /* prior for gamma shape parameter              */
+    char        shapePr[100];      /* prior for gamma/lnorm shape parameter        */
     MrBFlt      shapeFix;
     MrBFlt      shapeUni[2];
     MrBFlt      shapeExp;
@@ -1025,19 +1026,19 @@ typedef struct model
     MrBFlt      clockRateGamma[2];
     MrBFlt      clockRateExp;
     MrBFlt      clockRateFix;
-    char        popSizePr[100];        /* prior on population size                     */
+    char        popSizePr[100];        /* prior on population size                      */
     MrBFlt      popSizeFix;
     MrBFlt      popSizeUni[2];
     MrBFlt      popSizeLognormal[2];
     MrBFlt      popSizeGamma[2];
     MrBFlt      popSizeNormal[2];
-    char        popVarPr[100];         /* prior on pop. size variation across tree     */
-    char        growthPr[100];         /* prior on coalescence growth rate             */
+    char        popVarPr[100];         /* prior on pop. size variation across tree      */
+    char        growthPr[100];         /* prior on coalescence growth rate              */
     MrBFlt      growthFix;
     MrBFlt      growthUni[2];
     MrBFlt      growthExp;
     MrBFlt      growthNorm[2];
-    char        cppRatePr[100];        /* prior on CPP rate                            */
+    char        cppRatePr[100];        /* prior on CPP rate                             */
     MrBFlt      cppRateFix;
     MrBFlt      cppRateExp;
     char        cppMultDevPr[100];     /* prior on CPP rate multiplier Lognormal variance */
@@ -1200,8 +1201,8 @@ typedef struct modelinfo
     int         isTiNeeded[20];             /* marks whether a trans prob matrix is needed  */
 
     /* Gibbs sampling of gamma site rate parameters */
-    CLFlt       ***catLike;                 /* likelihood for Gibbs sampling of gamma */
-    CLFlt       ***catLnScaler;             /* scaler for Gibbs sampling of gamma */
+    CLFlt       ***catLike;                 /* likelihood for Gibbs sampling of gamma       */
+    CLFlt       ***catLnScaler;             /* scaler for Gibbs sampling of gamma           */
     int         gibbsGamma;                 /* flags whether Gibbs sampling of discrete gamma is used */
     int         gibbsFreq;                  /* frequency of Gibbs resampling of discrete gamma */
     
@@ -1292,7 +1293,7 @@ typedef struct modelinfo
     int*        cumulativeScaleIndices;     /* array of cumulative scale indices            */
     int         rescaleBeagleAll;           /* set to rescale all nodes                     */
     int*        rescaleFreq;                /* rescale frequency for each chain's tree      */
-    int         rescaleFreqOld;             /* holds rescale frequency of current state  */
+    int         rescaleFreqOld;             /* holds rescale frequency of current state     */
     int         recalculateScalers;         /* shoud we recalculate scalers for current state YES/NO */
     int*        succesCount;                /* count number of succesful computation since last reset of scalers */
     int**       isScalerNode;               /* for each node and chain set to YES if scaled node */
@@ -1354,18 +1355,18 @@ typedef struct sumt
 
 typedef struct comptree
     {
-    char        comptFileName1[120];    /* name of first input file                      */
-    char        comptFileName2[120];    /* name of second input file                     */
-    char        comptOutfile[120];      /* name of output file                           */
-    int         burnin;                 /* actual burnin used when parsing tree files    */
-    MrBFlt      minPartFreq;            /* use partitions with frequency >= minPartFreq  */
+    char        comptFileName1[120];   /* name of first input file                      */
+    char        comptFileName2[120];   /* name of second input file                     */
+    char        comptOutfile[120];     /* name of output file                           */
+    int         burnin;                /* actual burnin used when parsing tree files    */
+    MrBFlt      minPartFreq;           /* use partitions with frequency >= minPartFreq  */
     } Comptree;
 
 typedef struct sump
     {
     char        sumpFileName[100];     /* name of input file                            */
-    char        sumpOutfile[120];      /* name of output file                            */
-    //int           plot;                  /* output plot (y/n)?                            */
+    char        sumpOutfile[120];      /* name of output file                           */
+    //int       plot;                  /* output plot (y/n)?                            */
     int         table;                 /* output table (y/n)?                           */
     int         margLike;              /* output marginal likelihood (y/n)?             */
     int         numRuns;               /* number of independent analyses to summarize   */
@@ -1376,7 +1377,7 @@ typedef struct sump
 
 typedef struct sumss
     {
-    //int           plot;                  /* output plot (y/n)?                            */
+    //int       plot;                  /* output plot (y/n)?                            */
     int         numRuns;               /* number of independent analyses to summarize   */
     int         allRuns;               /* should data for all runs be printed (yes/no)? */
     int         stepToPlot;            /* Which step to plot in the step plot           */
@@ -1484,9 +1485,9 @@ extern int              compMatrixRowSize;                      /* row size of c
 extern Comptree         comptreeParams;                         /* holds parameters for comparetree command      */
 extern char             **constraintNames;                      /* holds names of constraints                    */
 extern BitsLong         **definedConstraint;                    /* holds information about defined constraints   */
-extern BitsLong        **definedConstraintTwo;                  /* bitfields representing second taxa sets of defined constraints (used for PARTIAL constraints)                                  */
-extern BitsLong        **definedConstraintPruned;               /* bitfields representing taxa sets of defined constraints after delited taxa are removed                                         */
-extern BitsLong        **definedConstraintTwoPruned;            /* bitfields representing second taxa sets of defined constraints  after delited taxa are removed(used for PARTIAL constraints)   */
+extern BitsLong         **definedConstraintTwo;                 /* bitfields representing second taxa sets of defined constraints (for PARTIAL constraints) */
+extern BitsLong         **definedConstraintPruned;              /* bitfields representing taxa sets of defined constraints after delited taxa are removed */
+extern BitsLong         **definedConstraintTwoPruned;           /* bitfields representing second taxa sets of defined constraints after delited taxa are removed (for PARTIAL constraints) */
 extern int              dataType;                               /* type of data                                  */
 extern Calibration      defaultCalibration;                     /* default model settings                        */
 extern ModelParams      defaultModel;                           /* default model settings                        */
@@ -1665,8 +1666,8 @@ extern MrBFlt           vtPi[20];                    /* stationary frequencies f
 extern MrBFlt           blosPi[20];                  /* stationary frequencies for Blosum62 model    */
 extern MrBFlt           lgPi[20];                    /* stationary frequencies for LG model          */
 
-#if defined (PRINT_RATEMULTIPLIERS_CPP)
-extern FILE             *rateMultfp;
+#if defined (PRINT_DUMP)
+FILE                    *dumpFile;                   /* for debugging logs */
 #endif
 
 #if defined (MPI_ENABLED)
