@@ -23,7 +23,7 @@
 #include    "proposal.h"
 #include    "utils.h"
 
-const char* const svnRevisionBestC = "$Rev: 895 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
+const char* const svnRevisionBestC = "$Rev: 1002 $";   /* Revision keyword which is expended/updated by svn on each commit/update */
 
 /****************************** Local functions converted by Fredrik from BEST code *****************************/
 int         CompareDepths (const void *x, const void *y);
@@ -68,8 +68,8 @@ void AllocateBestChainVariables (void)
             SetBit(i, speciesPairSets[index]);
             SetBit(j, speciesPairSets[index]);
             index++;
+            }
         }
-    }
 
     /* allocate species for depthMatrix */
     depthMatrix = SafeCalloc (numUpperTriang, sizeof(double));
@@ -128,7 +128,7 @@ int CompareNodesByX (const void *x, const void *y) {
             return 1;
         else
             return 0;
-    }
+        }
 }
 
 
@@ -200,6 +200,7 @@ int FillSpeciesTreeParams (RandLong *seed, int fromChain, int toChain)
         FreeBestChainVariables();
 
     return (NO_ERROR);
+    MrBayesPrint ("%lf", *seed); /* just because I am tired of seeing the unused parameter error msg */
 }
 
 
@@ -354,6 +355,7 @@ int GetMeanDist (Tree *speciesTree, double *minDepthMatrix, double *mean) {
         ResetTreePartitions(speciesTree);
 
     return (NO_ERROR);
+    MrBayesPrint ("%lf", *minDepthMatrix); /* just because I am tired of seeing the unused parameter error msg */
 }
 
 
@@ -543,9 +545,10 @@ int GetSpeciesTreeFromMinDepths (Tree* speciesTree, double *depthMatrix) {
         p = &polyTree->nodes[FirstTaxonInPartition(minDepth[i].pairSet, nLongsNeeded)];
         
         // Descend tree until we find a node within which the pair set is nested
-        do {
+        do  {
             p = p->anc;
-        } while (!IsPartNested(minDepth[i].pairSet, p->partition, nLongsNeeded));
+            }
+        while (!IsPartNested(minDepth[i].pairSet, p->partition, nLongsNeeded));
 
         if (p->left->sib->sib != NULL) {
             // This node is still a polytomy
@@ -595,7 +598,7 @@ int GetSpeciesTreeFromMinDepths (Tree* speciesTree, double *depthMatrix) {
         else if (p == polyTree->root && p->depth < 0.0) {
             // This is the first time we hit the root of the tree && it is resolved
             p->depth = minDepth[i].depth;
-            // assert (p->depth > 0.0);
+            assert (p->depth > 0.0);
             }
         // other cases should not be added to tree
         }
@@ -899,10 +902,10 @@ double LnPriorProbGeneTree (Tree *geneTree, double mu, Tree *speciesTree, double
             assert (q->x == p->index);
 
             if (k == p->x)
-                timeInterval = (q->nodeDepth - p->nodeDepth) / mu;
+                timeInterval = q->nodeDepth - p->nodeDepth;
             else {
                 r = geneTree->intDownPass[index-1];
-                timeInterval = (q->nodeDepth - r->nodeDepth) / mu;
+                timeInterval = q->nodeDepth - r->nodeDepth;
             }
 
             lnProb -= (k * (k - 1) * timeInterval) / theta;
@@ -953,7 +956,7 @@ double LnPriorProbGeneTree (Tree *geneTree, double mu, Tree *speciesTree, double
 double LnProposalProbSpeciesTree (Tree *speciesTree, double *depthMatrix, double expRate)
 {
     int         i, left, right, index, nLongsNeeded, freeBitsets;
-    double      dist, normConst, negLambdaX, eNegLambdaX, density, prob,
+    double      dist, normConst=1.0, negLambdaX=0.0, eNegLambdaX, density, prob,
                 sumDensRatio, prodProb, lnProb;
     TreeNode    *p;
 
@@ -981,29 +984,31 @@ double LnProposalProbSpeciesTree (Tree *speciesTree, double *depthMatrix, double
             for (right = FirstTaxonInPartition(p->right->partition, nLongsNeeded); right < numSpecies; right = NextTaxonInPartition(right, p->right->partition, nLongsNeeded))
                 {
                 p->x++;
-                index         = UpperTriangIndex(left, right, numSpecies);
-                assert (index < numSpecies*(numSpecies - 1) / 2);
+                index         = UpperTriangIndex(left, right, numSpecies);  assert (index < numSpecies*(numSpecies - 1) / 2);
                 dist          = depthMatrix[index] - p->nodeDepth;          // distance between depth matrix entry and actual species-tree node
                 normConst     = 1.0 - exp(-expRate * depthMatrix[index]);   // normalization constant because of truncation of exp distribution
                 negLambdaX    = - expRate * dist;
                 eNegLambdaX   = exp(negLambdaX);
                 density       = expRate * eNegLambdaX / normConst;      // density for x == dist, f(dist)
-                prob          = 1.0 - eNegLambdaX / normConst;          // cumulative prob for x <= dist, F(dist)
-                sumDensRatio += density / prob;
+                prob          = (1.0 - eNegLambdaX) / normConst;        // cumulative prob for x <= dist, F(dist)
+                sumDensRatio += density / prob;                         // warning: if dist==0, prob is ZERO!
                 prodProb     *= prob;
                 }
             }
         if (p->x == 1)
             lnProb += log(expRate) + negLambdaX - log(normConst);
         else
-            lnProb += log (sumDensRatio * prodProb);
+            lnProb += log(sumDensRatio * prodProb);
         }
 
+    // to avoid lnProposalProb is NaN at initial steps
+    if (lnProb != lnProb)  lnProb = 0.0;
+    
     // Free partitions if appropriate
     if (freeBitsets == YES)
         FreeTreePartitions(speciesTree);
 
-    return (NO_ERROR);
+    return (lnProb);
 }
 
 
@@ -1092,7 +1097,7 @@ int ModifyDepthMatrix (double expRate, double *depthMatrix, RandLong *seed)
     for (i=0; i<numUpperTriang; i++)
         {
         interval = depthMatrix[i];
-        u = RandomNumber (seed);
+        u = RandomNumber(seed);
         delta = log (1.0 - u*(1.0 - exp(-expRate*interval))) / (-expRate);
         assert (delta <= interval);
         depthMatrix[i] -= delta;
@@ -1151,6 +1156,7 @@ int Move_GeneTree1 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
 
     // Get forward lambda
     GetMeanDist(oldSpeciesTree, depthMatrix, &mean);
+    // if (mean < 1E-6) mean = 1E-6;
     forwardLambda = 1.0 / mean;
 
     // Calculate joint probability of old gene trees and old species tree
@@ -1182,6 +1188,7 @@ int Move_GeneTree1 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
 
     // Get backward lambda
     GetMeanDist(newSpeciesTree, depthMatrix, &mean);
+    // if (mean < 1E-6) mean = 1E-6;
     backwardLambda = 1.0 / mean;
 
     // Get proposal probability of old species tree
@@ -1253,6 +1260,7 @@ int Move_GeneTree2 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
 
     // Get forward lambda
     GetMeanDist(oldSpeciesTree, depthMatrix, &mean);
+    // if (mean < 1E-6) mean = 1E-6;
     forwardLambda = 1.0 / mean;
 
     // Calculate joint probability of old gene trees and old species tree
@@ -1284,6 +1292,7 @@ int Move_GeneTree2 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
 
     // Get backward lambda
     GetMeanDist(newSpeciesTree, depthMatrix, &mean);
+    // if (mean < 1E-6) mean = 1E-6;
     backwardLambda = 1.0 / mean;
 
     // Get proposal probability of old species tree
@@ -1339,7 +1348,7 @@ int Move_GeneTree3 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
     geneTrees = (Tree **) SafeCalloc (2*numGeneTrees, sizeof(Tree *));
     for (i=0; i<m->speciesTree->nSubParams; i++) {
         geneTrees[i] = GetTree(m->speciesTree->subParams[i], chain, state[chain]);
-    }
+        }
 
     // Allocate space for depth matrix copy
     numUpperTriang = numSpecies * (numSpecies - 1) / 2;
@@ -1355,12 +1364,13 @@ int Move_GeneTree3 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
 
     // Get forward lambda
     GetMeanDist(oldSpeciesTree, depthMatrix, &mean);
+    // if (mean < 1E-6) mean = 1E-6;
     forwardLambda = 1.0 / mean;
 
     // Calculate joint probability of old gene trees and old species tree
     oldLnProb = LnJointGeneTreeSpeciesTreePr(geneTrees, numGeneTrees, oldSpeciesTree, chain);
 
-    // Modify the picked gene tree using code from a regular MrBayes move (no tuning parameter here, so passing on mvp is OK)
+    // Modify the picked gene tree using code from a regular MrBayes move
     Move_ParsSPRClock(param, chain, seed, lnPriorRatio, lnProposalRatio, mvp);
 
     // Update the min depth matrix
@@ -1379,13 +1389,14 @@ int Move_GeneTree3 (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRati
         free (geneTrees);
         free (oldMinDepths);
         return (NO_ERROR);
-    }
+        }
    
     // Calculate joint probability of new gene trees and new species tree
     newLnProb = LnJointGeneTreeSpeciesTreePr(geneTrees, numGeneTrees, newSpeciesTree, chain);
 
     // Get backward lambda
     GetMeanDist(newSpeciesTree, depthMatrix, &mean);
+    // if (mean < 1E-6) mean = 1E-6;
     backwardLambda = 1.0 / mean;
 
     // Get proposal probability of old species tree
@@ -1504,7 +1515,7 @@ int Move_NodeSliderGeneTree (Param *param, int chain, RandLong *seed, MrBFlt *ln
 
     /* pick the new node depth */
     oldDepth = p->nodeDepth;
-    newDepth = oldDepth + (RandomNumber (seed) - 0.5) * window;
+    newDepth = oldDepth + (RandomNumber(seed) - 0.5) * window;
     
     /* reflect the new node depth */
     while (newDepth < minDepth || newDepth > maxDepth)
@@ -1611,21 +1622,10 @@ int Move_NodeSliderGeneTree (Param *param, int chain, RandLong *seed, MrBFlt *ln
                 {
                 brlens[p->left->index] = p->left->length * (tk02Rate[p->left->index]+tk02Rate[p->index])/2.0;
                 brlens[p->right->index] = p->right->length * (tk02Rate[p->right->index]+tk02Rate[p->index])/2.0;
-                if (brlens[p->left->index]  < RELBRLENS_MIN || brlens[p->left->index]  > RELBRLENS_MAX ||
-                    brlens[p->right->index] < RELBRLENS_MIN || brlens[p->right->index] > RELBRLENS_MAX)
-                    {
-                    abortMove = YES;
-                    return (NO_ERROR);
-                    }
                 }
             if (p->anc->anc != NULL)
                 {
                 brlens[p->index] = p->length * (tk02Rate[p->index]+tk02Rate[p->anc->index])/2.0;
-                if (brlens[p->index] < RELBRLENS_MIN || brlens[p->index] > RELBRLENS_MAX)
-                    {
-                    abortMove = YES;
-                    return (NO_ERROR);
-                    }
                 }
             }
         else if ( subParm->paramType == P_IGRBRANCHRATES ||
@@ -1655,21 +1655,10 @@ int Move_NodeSliderGeneTree (Param *param, int chain, RandLong *seed, MrBFlt *ln
                 {
                 brlens[p->left->index ] = igrRate[p->left->index ] * p->left->length;
                 brlens[p->right->index] = igrRate[p->right->index] * p->right->length;
-                if (brlens[p->left->index]  < RELBRLENS_MIN || brlens[p->left->index]  > RELBRLENS_MAX ||
-                    brlens[p->right->index] < RELBRLENS_MIN || brlens[p->right->index] > RELBRLENS_MAX)
-                    {
-                    abortMove = YES;
-                    return (NO_ERROR);
-                    }
                 }
             if (p->anc->anc != NULL)
                 {
                 brlens[p->index] = igrRate[p->index] * p->length;
-                if (brlens[p->index] < RELBRLENS_MIN || brlens[p->index] > RELBRLENS_MAX)
-                    {
-                    abortMove = YES;
-                    return (NO_ERROR);
-                    }
                 }
             }
         }
@@ -1740,7 +1729,7 @@ int Move_SpeciesTree (Param *param, int chain, RandLong *seed, MrBFlt *lnPriorRa
         free (modMinDepths);
         free (geneTrees);
         return (NO_ERROR);
-    }
+        }
 
     /* get lambda for back move */
     GetMeanDist(newSpeciesTree, depthMatrix, &mean);
@@ -1791,9 +1780,9 @@ void ShowUpperTriangMatrix (double *values, int squareSize)
         for (j=i+1; j<squareSize; j++) {
             printf ("%.6f ", values[index]);
             index++;
-        }
+            }
         printf ("\n");
-    }
+        }
     printf ("\n");
 }
 
